Module dijkstra

Module dijkstra 

Dijkstra’s shortest path algorithm implementation. Dijkstra’s shortest path algorithm implementation.

Structs

DijkstraResult
Result of Dijkstra’s shortest path algorithm.

Functions

dijkstra
[Generic] Compute shortest paths from node source to all other nodes using Dijkstra’s algorithm.
dijkstra_path
[Generic] Compute shortest path from source to target using Dijkstra’s algorithm.