DijkstraResult

Struct DijkstraResult 

pub struct DijkstraResult<NodeId, EdgeWeight> {
    pub distances: Vec<EdgeWeight>,
    pub predecessors: Vec<Option<NodeId>>,
}
Result of Dijkstra’s shortest path algorithm.

Contains the distances from the source node to all other nodes, and the predecessor of each node along the shortest path.

Fields

distances: Vec<EdgeWeight>predecessors: Vec<Option<NodeId>>