ParametricAPI

Trait ParametricAPI 

pub trait ParametricAPI<E, R>
where R: Copy + PartialOrd, E: Clone,
{ // Required methods fn distance(&self, ratio: &R, edge: &EdgeReference<'_, R>) -> R; fn zero_cancel(&self, cycle: &[EdgeReference<'_, R>]) -> R; }
API trait for parametric shortest path problems.

Implement this trait to define how distances are computed and how to find the ratio that cancels a cycle.

Required Methods

fn distance(&self, ratio: &R, edge: &EdgeReference<'_, R>) -> R

fn zero_cancel(&self, cycle: &[EdgeReference<'_, R>]) -> R

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors